.. _taxbrain:

Tax-Brain Class Object
======================================

**taxbrain**

taxbrain.taxbrain
------------------------------------------

.. currentmodule:: taxbrain.taxbrain

.. autoclass:: TaxBrain
  :members: run, weighted_totals, multi_var_table, distribution_table,
    differences_table
